summaryrefslogtreecommitdiffstats
path: root/karbon/karbon_factory.cc
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/karbon_factory.cc')
-rw-r--r--karbon/karbon_factory.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/karbon/karbon_factory.cc b/karbon/karbon_factory.cc
index d8356184..041de7ff 100644
--- a/karbon/karbon_factory.cc
+++ b/karbon/karbon_factory.cc
@@ -76,7 +76,7 @@ KarbonFactory::~KarbonFactory()
}
KParts::Part*
-KarbonFactory::createPartObject( TQWidget* tqparentWidget, const char* widgetName,
+KarbonFactory::createPartObject( TQWidget* parentWidget, const char* widgetName,
TQObject* tqparent, const char* name, const char* classname, const TQStringList& )
{
// If classname is "KoDocument", our host is a koffice application
@@ -84,10 +84,10 @@ KarbonFactory::createPartObject( TQWidget* tqparentWidget, const char* widgetNam
// single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
// tqparentWidget and widgetName are used by KoDocument for the
// "readonly+singleView" case.
KarbonPart* part =
- new KarbonPart( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
+ new KarbonPart( parentWidget, widgetName, tqparent, name, !bWantKoDocument );
if( !bWantKoDocument )
part->setReadWrite( false );
@@ -84,10 +84,10 @@ KarbonFactory::createPartObject( TQWidget* tqparentWidget, const char* widgetNam
// single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- // tqparentWidget and widgetName are used by KoDocument for the
+ // parentWidget and widgetName are used by KoDocument for the
// "readonly+singleView" case.
KarbonPart* part =